==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/GREENHOUSEGASID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GREENHOUSEGASID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GREENHOUSEGASID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GREENHOUSEGASCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GREENHOUSEGASID_Type", propOrder = {
    "greenhousegascode",
    "description"
})
public class GREENHOUSEGASID_Type {

    @XmlElement(name = "GREENHOUSEGASCODE", required = true)
    protected String greenhousegascode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété greenhousegascode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGREENHOUSEGASCODE() {
        return greenhousegascode;
    }

    /**
     * Définit la valeur de la propriété greenhousegascode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGREENHOUSEGASCODE(String value) {
        this.greenhousegascode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/GREENHOUSEGASID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GREENHOUSEGASID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GREENHOUSEGASID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GREENHOUSEGASCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GREENHOUSEGASID_Type", propOrder = {
    "greenhousegascode",
    "description"
})
public class GREENHOUSEGASID_Type {

    @XmlElement(name = "GREENHOUSEGASCODE", required = true)
    protected String greenhousegascode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the greenhousegascode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGREENHOUSEGASCODE() {
        return greenhousegascode;
    }

    /**
     * Sets the value of the greenhousegascode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGREENHOUSEGASCODE(String value) {
        this.greenhousegascode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
